# 🌀 bluer-sbc

🌀 `bluer-sbc` is a [`bluer-ai`](https://github.com/kamangir/bluer-ai) plugin for edge computing on [single board computers](https://github.com/kamangir/blue-bracket). 

## installation

```bash
pip install bluer_sbc

# @env dot list
@env dot cp <env-name> local
```

## aliases

[@camera](./bluer_sbc/docs/aliases/camera.md), 
[@sbc rpi](./bluer_sbc/docs/aliases/sbc.md), 
[@sbc <hardware>](./bluer_sbc/docs/aliases/hardware.md).

## designs

|   |   |   |
| --- | --- | --- |
| [`swallow head`](./bluer_sbc/docs/swallow-head.md) [![image](https://github.com/kamangir/assets2/blob/main/swallow/design/head-v1/01.jpg?raw=true)](./bluer_sbc/docs/swallow-head.md)  | [`swallow`](./bluer_sbc/docs/swallow.md) [![image](https://github.com/kamangir/assets2/blob/main/swallow/design/v5/01.jpg?raw=true)](./bluer_sbc/docs/swallow.md)  | [`battery bus`](./bluer_sbc/docs/battery-bus.md) [![image](https://github.com/kamangir/assets2/raw/main/battery-bus/20251007_221902.jpg)](./bluer_sbc/docs/battery-bus.md)  |
| [`adapter bus`](./bluer_sbc/docs/adapter-bus.md) [![image](https://github.com/kamangir/assets2/raw/main/adapter-bus/20251017_222911.jpg)](./bluer_sbc/docs/adapter-bus.md)  | [`ultrasonic-sensor-tester`](./bluer_sbc/docs/ultrasonic-sensor-tester.md) [![image](https://github.com/kamangir/assets2/blob/main/ultrasonic-sensor-tester/00.jpg?raw=true)](./bluer_sbc/docs/ultrasonic-sensor-tester.md)  | [`bryce`](./bluer_sbc/docs/bryce.md) [![image](https://github.com/kamangir/assets2/blob/main/bryce/08.jpg?raw=true)](./bluer_sbc/docs/bryce.md)  |
| [`cheshmak`](./bluer_sbc/docs/cheshmak.md) [![image](https://github.com/kamangir/assets2/blob/main/cheshmak/01.png?raw=true)](./bluer_sbc/docs/cheshmak.md)  | [`nafha`](./bluer_sbc/docs/nafha) [![image](https://github.com/kamangir/assets2/blob/main/nafha/01.png?raw=true)](./bluer_sbc/docs/nafha)  | [`shelter`](./bluer_sbc/docs/shelter) [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251104_000755.jpg)](./bluer_sbc/docs/shelter)  |
| [`blue3`](https://github.com/kamangir/blue-bracket/blob/main/designs/blue3.md) [![image](https://github.com/kamangir/blue-bracket/raw/main/images/blue3-1.jpg)](https://github.com/kamangir/blue-bracket/blob/main/designs/blue3.md)  | [`chenar-grove`](https://github.com/kamangir/blue-bracket/blob/main/designs/chenar-grove.md) [![image](https://github.com/kamangir/blue-bracket/raw/main/images/chenar-grove-1.jpg)](https://github.com/kamangir/blue-bracket/blob/main/designs/chenar-grove.md)  | [`cube`](https://github.com/kamangir/blue-bracket/blob/main/designs/cube.md) [![image](https://github.com/kamangir/blue-bracket/raw/main/images/cube-1.jpg)](https://github.com/kamangir/blue-bracket/blob/main/designs/cube.md)  |
| [`eye_nano`](https://github.com/kamangir/blue-bracket/blob/main/designs/eye_nano.md) [![image](https://github.com/kamangir/blue-bracket/raw/main/images/eye_nano-1.jpg)](https://github.com/kamangir/blue-bracket/blob/main/designs/eye_nano.md)  |  |  |

## shortcuts

|   |
| --- |
| [`parts`](./bluer_sbc/docs/parts) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/grid.png)](./bluer_sbc/docs/parts)  |

---

> 🌀 [`blue-sbc`](https://github.com/kamangir/blue-sbc) for the [Global South](https://github.com/kamangir/bluer-south).

---


[![pylint](https://github.com/kamangir/bluer-sbc/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/bluer-sbc/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/bluer-sbc/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/bluer-sbc/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/bluer-sbc/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/bluer-sbc/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/bluer-sbc.svg)](https://pypi.org/project/bluer-sbc/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/bluer-sbc)](https://pypistats.org/packages/bluer-sbc)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 🌀 [`bluer_sbc-9.168.1`](https://github.com/kamangir/bluer-sbc).

